==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/integrationspaces/kotlin/outputs/GetApplicationResourceResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.integrationspaces.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * A resource under application.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property name The name of the resource
 * @property provisioningState The status of the last operation.
 * @property resourceId The Arm id of the application resource.
 * @property resourceKind The kind of the application resource.
 * @property resourceType The type of the application resource.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetApplicationResourceResult(
    public val id: String,
    public val name: String,
    public val provisioningState: String,
    public val resourceId: String,
    public val resourceKind: String? = null,
    public val resourceType: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.integrationspaces.outputs.GetApplicationResourceResult):
            GetApplicationResourceResult = GetApplicationResourceResult(
            id = javaType.id(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            resourceId = javaType.resourceId(),
            resourceKind = javaType.resourceKind().map({ args0 -> args0 }).orElse(null),
            resourceType = javaType.resourceType(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.integrationspaces.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/integrationspaces/kotlin/outputs/GetApplicationResourceResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.integrationspaces.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * A resource under application.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property name The name of the resource
 * @property provisioningState The status of the last operation.
 * @property resourceId The Arm id of the application resource.
 * @property resourceKind The kind of the application resource.
 * @property resourceType The type of the application resource.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetApplicationResourceResult(
    public val id: String,
    public val name: String,
    public val provisioningState: String,
    public val resourceId: String,
    public val resourceKind: String? = null,
    public val resourceType: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.integrationspaces.outputs.GetApplicationResourceResult): GetApplicationResourceResult = GetApplicationResourceResult(
            id = javaType.id(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            resourceId = javaType.resourceId(),
            resourceKind = javaType.resourceKind().map({ args0 -> args0 }).orElse(null),
            resourceType = javaType.resourceType(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.integrationspaces.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}
